Utilities
=========


.. automodule:: antidote._config
    :members:

    .. py:data:: config
        :type: antidote._config.Config

        Singleton instance of :py:class:`.Config`


.. automodule:: antidote.utils
    :members: is_compiled, validated_scope, validate_injection
